==> dls-python-copier-template-example-0.1.tar.gz: dls-python-copier-template-example-0.1/README.md <==
[![CI](https://github.com/DiamondLightSource/python-copier-template-example/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/python-copier-template-example/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/python-copier-template-example/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/python-copier-template-example)
[![PyPI](https://img.shields.io/pypi/v/dls-python-copier-template-example.svg)](https://pypi.org/project/dls-python-copier-template-example)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# python_copier_template_example

This is where you should write a short paragraph that describes what your module does,
how it does it, and why people should use it.

Source          | <https://github.com/DiamondLightSource/python-copier-template-example>
:---:           | :---:
PyPI            | `pip install dls-python-copier-template-example`
Documentation   | <https://diamondlightsource.github.io/python-copier-template-example>
Releases        | <https://github.com/DiamondLightSource/python-copier-template-example/releases>

This is where you should put some images or code snippets that illustrate
some relevant examples. If it is a library then you might put some
introductory code here:

```python
from python_copier_template_example import __version__

print(f"Hello python_copier_template_example {__version__}")
```

Or if it is a commandline tool then you might put some example commands here:

```
python -m python_copier_template_example --version
```

<!-- README only content. Anything below this line won't be included in index.md -->

See https://diamondlightsource.github.io/python-copier-template-example for more detailed documentation.

==> dls-python-copier-template-example-0.3.1a1.tar.gz: dls-python-copier-template-example-0.3.1a1/README.md <==
[![CI](https://github.com/DiamondLightSource/python-copier-template-example/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/python-copier-template-example/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/python-copier-template-example/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/python-copier-template-example)
[![PyPI](https://img.shields.io/pypi/v/dls-python-copier-template-example.svg)](https://pypi.org/project/dls-python-copier-template-example)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# python_copier_template_example

An expanded https://github.com/DiamondLightSource/python-copier-template to illustrate how it looks with all the options enabled.

This is where you should write a short paragraph that describes what your module does,
how it does it, and why people should use it.

Source          | <https://github.com/DiamondLightSource/python-copier-template-example>
:---:           | :---:
PyPI            | `pip install dls-python-copier-template-example`
Documentation   | <https://diamondlightsource.github.io/python-copier-template-example>
Releases        | <https://github.com/DiamondLightSource/python-copier-template-example/releases>

This is where you should put some images or code snippets that illustrate
some relevant examples. If it is a library then you might put some
introductory code here:

```python
from python_copier_template_example import __version__

print(f"Hello python_copier_template_example {__version__}")
```

Or if it is a commandline tool then you might put some example commands here:

```
python -m python_copier_template_example --version
```

<!-- README only content. Anything below this line won't be included in index.md -->

See https://diamondlightsource.github.io/python-copier-template-example for more detailed documentation.
